/*
 * Copyright (c) 2001-2005 OFFIS, Tammo Freese.
 * This program is made available under the terms of the MIT License.
 */
package org.easymock.internal;

public class Result {
    private Object value;

    private boolean doThrow;

    private final Runnable callback;

    private Result(Object value, boolean doThrow, Runnable callback) {
        this.value = value;
        this.doThrow = doThrow;
        this.callback = callback;
    }

    public static Result createThrowResult(Throwable throwable) {
        return new Result(throwable, true, null);
    }

    public static Result createReturnResult(Object value) {
        return new Result(value, false, null);
    }

    public Result withCallback(Runnable runnable) {
        return new Result(value, doThrow, runnable);
    }

    public Object returnObjectOrThrowException() throws Throwable {
        callbackIfNeeded();
        if (doThrow) {
            throw new ThrowableWrapper((Throwable) value);
        } else {
            return value;
        }
    }

    private void callbackIfNeeded() {
        if (callback != null) {
            try {
                callback.run();
            } catch (Throwable t) {
            }
        }
    }

    public boolean hasCallback() {
        return this.callback != null;
    }

}
